summaryrefslogtreecommitdiffstats
path: root/sys/dev/ppbus
diff options
context:
space:
mode:
authorschweikh <schweikh@FreeBSD.org>2002-12-30 21:18:15 +0000
committerschweikh <schweikh@FreeBSD.org>2002-12-30 21:18:15 +0000
commit86f7487fb6a0b8dd9e3a699ad48d6e99504a67ff (patch)
treebd0234a8048c844b06483795cfb1fe4d34b68a4f /sys/dev/ppbus
parent338583ff7c1145c5e2deba34aed769eb7998286c (diff)
downloadFreeBSD-src-86f7487fb6a0b8dd9e3a699ad48d6e99504a67ff.zip
FreeBSD-src-86f7487fb6a0b8dd9e3a699ad48d6e99504a67ff.tar.gz
Fix typos, mostly s/ an / a / where appropriate and a few s/an/and/
Add FreeBSD Id tag where missing.
Diffstat (limited to 'sys/dev/ppbus')
-rw-r--r--sys/dev/ppbus/if_plip.c2
-rw-r--r--sys/dev/ppbus/ppi.c26
2 files changed, 14 insertions, 14 deletions
diff --git a/sys/dev/ppbus/if_plip.c b/sys/dev/ppbus/if_plip.c
index 6f72096..5ba4dc3 100644
--- a/sys/dev/ppbus/if_plip.c
+++ b/sys/dev/ppbus/if_plip.c
@@ -35,7 +35,7 @@
* This driver sends two bytes (0x08, 0x00) in front of each packet,
* to allow us to distinguish another format later.
*
- * Now added an Linux/Crynwr compatibility mode which is enabled using
+ * Now added a Linux/Crynwr compatibility mode which is enabled using
* IF_LINK0 - Tim Wilkinson.
*
* TODO:
diff --git a/sys/dev/ppbus/ppi.c b/sys/dev/ppbus/ppi.c
index d2cf4fd..e1bc241 100644
--- a/sys/dev/ppbus/ppi.c
+++ b/sys/dev/ppbus/ppi.c
@@ -207,13 +207,13 @@ ppiintr(void *arg)
switch (ppb_1284_get_state(ppbus)) {
/* accept IEEE1284 negociation then wakeup an waiting process to
* continue negociation at process level */
case PPB_FORWARD_IDLE:
/* Event 1 */
if ((ppb_rstr(ppbus) & (SELECT | nBUSY)) ==
(SELECT | nBUSY)) {
- /* IEEE1284 negociation */
+ /* IEEE1284 negotiation */
#ifdef DEBUG_1284
printf("N");
#endif
@@ -231,7 +231,7 @@ ppiintr(void *arg)
break;
}
/* wake up any process waiting for negociation from
* remote master host */
/* XXX should set a variable to warn the process about
@@ -326,7 +326,7 @@ ppiclose(dev_t dev, int flags, int fmt, struct thread *td)
*
* IEEE1284 compliant read.
*
* First, try negociation to BYTE then NIBBLE mode
* If no data is available, wait for it otherwise transfer as much as possible
*/
static int
@@ -345,7 +345,7 @@ ppiread(dev_t dev, struct uio *uio, int ioflag)
/* FALLTHROUGH */
case PPB_FORWARD_IDLE:
- /* if can't negociate NIBBLE mode then try BYTE mode,
+ /* if can't negotiate NIBBLE mode then try BYTE mode,
* the peripheral may be a computer
*/
if ((ppb_1284_negociate(ppbus,
@@ -407,11 +407,11 @@ error:
*
* Actually, this is the peripheral side of a remote IEEE1284 read
*
* The first part of the negociation (IEEE1284 device detection) is
* done at interrupt level, then the remaining is done by the writing
* process
*
* Once negociation done, transfer data
*/
static int
ppiwrite(dev_t dev, struct uio *uio, int ioflag)
@@ -434,9 +434,9 @@ ppiwrite(dev_t dev, struct uio *uio, int ioflag)
MS_RET(0)
};
- /* negociate ECP mode */
+ /* negotiate ECP mode */
if (ppb_1284_negociate(ppbus, PPB_ECP, 0)) {
- printf("ppiwrite: ECP negociation failed\n");
+ printf("ppiwrite: ECP negotiation failed\n");
}
while (!error && (len = min(uio->uio_resid, BUFSIZE))) {
@@ -462,12 +462,12 @@ ppiwrite(dev_t dev, struct uio *uio, int ioflag)
ppi_enable_intr(ppidev);
/* sleep until IEEE1284 negociation starts */
error = tsleep(ppi, PCATCH | PPBPRI, "ppiwrite", 0);
switch (error) {
case 0:
- /* negociate peripheral side with BYTE mode */
+ /* negotiate peripheral side with BYTE mode */
ppb_peripheral_negociate(ppbus, PPB_BYTE, 0);
break;
case EWOULDBLOCK:
@@ -480,7 +480,7 @@ ppiwrite(dev_t dev, struct uio *uio, int ioflag)
printf("N");
#endif
/* negociation done, write bytes to master host */
while ((len = min(uio->uio_resid, BUFSIZE)) != 0) {
uiomove(ppi->ppi_buffer, len, uio);
if ((error = byte_peripheral_write(ppbus,
@@ -207,13 +207,13 @@ ppiintr(void *arg)
switch (ppb_1284_get_state(ppbus)) {
- /* accept IEEE1284 negociation then wakeup an waiting process to
- * continue negociation at process level */
+ /* accept IEEE1284 negotiation then wakeup a waiting process to
+ * continue negotiation at process level */
case PPB_FORWARD_IDLE:
/* Event 1 */
@@ -231,7 +231,7 @@ ppiintr(void *arg)
break;
}
- /* wake up any process waiting for negociation from
+ /* wake up any process waiting for negotiation from
* remote master host */
/* XXX should set a variable to warn the process about
@@ -326,7 +326,7 @@ ppiclose(dev_t dev, int flags, int fmt, struct thread *td)
* IEEE1284 compliant read.
*
- * First, try negociation to BYTE then NIBBLE mode
+ * First, try negotiation to BYTE then NIBBLE mode
* If no data is available, wait for it otherwise transfer as much as possible
*/
@@ -407,11 +407,11 @@ error:
* Actually, this is the peripheral side of a remote IEEE1284 read
*
- * The first part of the negociation (IEEE1284 device detection) is
+ * The first part of the negotiation (IEEE1284 device detection) is
* done at interrupt level, then the remaining is done by the writing
* process
@@ -407,11 +407,11 @@ error:
* process
*
- * Once negociation done, transfer data
+ * Once negotiation done, transfer data
*/
static int
@@ -462,12 +462,12 @@ ppiwrite(dev_t dev, struct uio *uio, int ioflag)
ppi_enable_intr(ppidev);
- /* sleep until IEEE1284 negociation starts */
+ /* sleep until IEEE1284 negotiation starts */
error = tsleep(ppi, PCATCH | PPBPRI, "ppiwrite", 0);
switch (error) {
@@ -480,7 +480,7 @@ ppiwrite(dev_t dev, struct uio *uio, int ioflag)
printf("N");
#endif
- /* negociation done, write bytes to master host */
+ /* negotiation done, write bytes to master host */
while ((len = min(uio->uio_resid, BUFSIZE)) != 0) {
uiomove(ppi->ppi_buffer, len, uio);
OpenPOWER on IntegriCloud